# Copyright (c) MONAI Consortium
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#     http://www.apache.org/licenses/LICENSE-2.0
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import annotations

import unittest

from tests.test_utils import DistCall, DistTestCase


class DistributedCallTest(DistTestCase):
    def test_constructor(self):
        with self.assertRaises(ValueError):
            DistCall(nnodes=1, nproc_per_node=0)
        with self.assertRaises(ValueError):
            DistCall(nnodes=0, nproc_per_node=0)
        with self.assertRaises(ValueError):
            DistCall(nnodes=0, nproc_per_node=1)
        _ = DistCall(nnodes=1, nproc_per_node=1)


if __name__ == "__main__":
    unittest.main()
